@@ -11,6 +11,8 @@ import logging
 import shelve
 import json
 import re
+import socket
+import math
 
 from contextlib import closing # for Python2.6 compatibility
 
@@ -23,7 +25,7 @@ from boto.exception import S3ResponseError
 from beefish import decrypt, encrypt_file
 import aaargh
 
-__version__ = "0.3.5"
+__version__ = "0.3.6"
 
 DEFAULT_LOCATION = "us-east-1"
 DEFAULT_DESTINATION = "s3"
@@ -273,7 +275,13 @@ class GlacierBackend:
         if job.completed:
             log.info("Downloading...")
             encrypted_out = tempfile.TemporaryFile()
-            encrypted_out.write(job.get_output().read())
+
+            # Boto related, download the file in chunk
+            chunk_size = 4 * 1024 * 1024
+            num_chunks = int(math.ceil(job.archive_size / float(chunk_size)))
+            job._download_to_fileob(encrypted_out, num_chunks, chunk_size,
+                                     True, (socket.error,))
+
             encrypted_out.seek(0)
             return encrypted_out
         else:
@@ -405,7 +413,7 @@ def info(filename, destination=None, description=None, **kwargs):
     filename = filename.split("/")[-1]
     keys = match_filename(filename, destination if destination else DEFAULT_DESTINATION)
     if not keys:
-        log.info("No matching bakup found for " + str(filename))
+        log.info("No matching backup found for " + str(filename))
         key = None
     else:
         key = keys[0]
